
## Criação de Multi-Tenant - Ex: Site dos Professores

1. Acesse o diretório: `.../web/sites/`.
2. Faça uma cópia do arquivo `example.sites.php` para `sites.php`.
3. No arquivo `sites.php`, insira no final:
   ```php
   $sites["<dominio>"] = "<diretorio_para_dominio>";
   ```
   **Exemplo:**
   ```php
   $sites["site1.com.br"] = "site1";
   ```
4. Salve o arquivo.

5. No diretório atual, crie os diretórios para os sites:
   ```
   site1/files/translations
   ```

6. Copie o arquivo `default.settings.php` do diretório `default/` para `site1`.

7. Dê permissão com o comando:
   ```bash
   chmod -R 777 site1
   ```

8. Acesse o navegador com base no domínio informado para realizar a instalação do site.

---

## Sobre o Drupal

### Encapsulamento

- O Drupal utiliza bastante encapsulamento de elementos: blocos, layouts, parágrafos.
- Criamos um parágrafo, definimos seu tipo (texto, imagem etc.).
- Associamos esse tipo de parágrafo ao conteúdo onde ele será exibido.
- A mesma lógica vale para blocos e layouts de blocos.

### Funcionalidades dos Blocos

- Estrutura padrão de blocos conforme o tema, disponível em todas as páginas.
- Blocos são fixos na tela (não reposicionáveis livremente).
- É possível definir a visibilidade do bloco por página.
- Criação de novos blocos:
  - Blocos básicos.
  - Blocos com DXPR Builder (drag and drop).
- DXPR Builder permite maior estilização (texto, imagens etc.).

### Funcionalidades de Layouts/Views

- Após criar ou editar blocos, podemos organizar os layouts por seção:
  - Ex: cabeçalho, menu, conteúdo principal, sidebar, rodapé...
- Blocos básicos têm pouca estilização.
- Blocos com DXPR Builder oferecem mais recursos (texto, imagem).
- A estrutura padrão já vem configurada no site default.
- **Views** são formas de visualizar conteúdo (ajuste fino):
  - Ex: ID da publicação, tags, tipo de conteúdo.
- Podemos criar views para exibir, por exemplo, notícias.

### Construção de Página com o DXPR Builder

- **Módulo DXPR Builder:**  
  [https://www.drupal.org/forum/support/theme-development/2024-03-12/drupal-10-bootstrap-5](https://www.drupal.org/forum/support/theme-development/2024-03-12/drupal-10-bootstrap-5)
- Estilo Drag and Drop sem código.
- Permite criação de:
  - Carrosséis
  - Textos
  - Colunas
  - Linhas
- 907 usuários relataram uso com 12 bugs em aberto.
- Recomendado para páginas como "Home", "Quem somos".
- Para notícias, usar módulos como Layout Paragraphs com estrutura fixa.

### Dificuldades com Estilização de Temas

- Drupal tem limitações na estilização de temas.
- Temas com maior liberdade geralmente são pagos.
- Temas usados:
  - **Bootstrap**
  - **DXPR**
- Alguns requerem linha de comando para configurar.

### Tema Bootstrap 5 (via código com SASS)

- Drupal nativo não permite alterar estilos facilmente.
- Bootstrap 5 oferece:
  - Tema simples
  - Criação de subtemas
  - Estilização via SASS
- Arquivos importantes:
  - `_variables_bootstrap5.scss`
  - `_variable_drupal.scss`
  - `style.css`

### Tema Zero Point  
[https://www.drupal.org/project/zeropoint](https://www.drupal.org/project/zeropoint)

Permite estilização básica:
- Tamanho dos blocos
- Responsividade
- Menu principal
- Uso de sidebars
- Cores de hover
- SEO
- Links sociais
- Carrossel
- Alguns ajustes via linha de comando

---

### Módulos Utilizados

- DXPR Builder – Estrutura de conteúdo
- Layout Paragraphs – Drag and drop
- EBT – Semelhante ao Layout Paragraphs
- Bootstrap5
- Zero Point (tema alternativo)

---

## Criação de Conteúdo

- Cada página no Drupal é baseada em um tipo de conteúdo:
  - Artigo
  - Página básica
  - Drag and drop (com DXPR)
- Drag and drop oferece autonomia na criação (texto, colunas, carrossel etc.)

### Barra de Pesquisa

- Encontrado problema de busca em alguns momentos (bug pontual).

### Instalação de Temas/Módulos via Composer

- Não é permitido instalar via botão "Adicionar novo".
- Instalação obrigatoriamente via linha de comando com **Composer** (gerenciador PHP).

### Busca por Temas No-Code

- Objetivo: estilizar o site sem código.
- Temas gratuitos têm limitações de personalização.

---

## Curva de Aprendizado do Drupal

- CMS gratuito e open-source.
- Necessita compreensão do funcionamento em **camadas**:
  - Nodes (dados publicados)
  - Módulos
  - Blocos e menus
  - Permissões
  - Templates

- Exemplo: criar parágrafo -> configurar tipo de conteúdo -> vincular a bloco.
- Alguns temas apresentam status como "sem versão estável".
- Seção "Detalhe de Status" mostra alertas e falhas de segurança.

---

## Problema com Domínio (Multi-Tenant)

---

## Tecnologias Citadas

- **CKEditor 5**
- **Twig** (debug de tema a partir do Drupal 9)
- **Drupal padrão**
- **Drupal headless**

---

## Ideias para Artigo

- **Pergunta-chave:** Existe alguma alternativa ao WordPress?
- **Introdução:** CMS, facilidade na criação de conteúdo.
- O que é um CMS
- CMS disponíveis
- CMS mais usados no Brasil e no mundo (Ásia, África, Europa, América do Norte)
- Diferenças entre Drupal e WordPress
- WordPress domina nas universidades brasileiras
- Drupal se destaca na Europa
- Problemas de segurança no WordPress (CVE’s, plugins como Elementor)
- Overhead no processo (ex: Zanata)
- Segurança no Drupal
- Experiência do usuário: prós e contras de cada CMS
- Busca por soluções no-code
- Nova proposta de CMS:
  - **Hugo + Strapi**
    - Hugo: site estático com tema
    - Strapi: backend para enviar conteúdo via JSON
    - Problemas de estilização com Hugo
    - Possibilidade de criar tema próprio

---

**Pergunta-chave:** Existe alguma alternativa ao WordPress?

- WordPress sofre com falhas de segurança
- Hugo + Strapi tem limitações de estilização

---

**Referência:**  
[https://www.drupal.org/docs/getting-started/understanding-drupal/overview-of-drupal](https://www.drupal.org/docs/getting-started/understanding-drupal/overview-of-drupal)
