
# Hugo - Gerador de Sites Estáticos

## O que é?

- **Hugo** é um gerador de sites estáticos e uma aplicação **Open Source** que auxilia o criador a gerenciar, publicar e divulgar seu conteúdo.
- Usado para criar:
  - Sites corporativos
  - Governamentais
  - Sem fins lucrativos
  - Educação
  - Notícias
  - Eventos e projetos
  - Blogs empresariais
  - Portfólios de imagem

## O que é um Site Estático?

- Site que **não possui ferramentas de gerenciamento de conteúdo dinâmico**.
- Modificações devem ser feitas diretamente no código.
- Ideal para desempenho, velocidade e segurança.

## Características

- Otimizado para velocidade (reputação de ser um dos mais rápidos - **~1ms**).
- Estrutura flexível, suporte multilíngue e sistema robusto de taxonomia.
- Backend gerenciado por **editores de texto**.

## O que é Markdown?

- **Markdown** é uma linguagem de marcação para formatação de texto.
- Exemplo: `*itálico*` ou `_itálico_`.
- Hugo suporta **Markdown** e **HTML**.

## Suporte a Backend

- É possível usar **API** com **Python/PHP** no backend.

## Linguagem

- Hugo é desenvolvido em **Go**.
- Suporta conteúdo em:
  - Markdown (MD)
  - HTML
  - JavaScript
  - CSS
  - JSON
  - AMP
  - YAML

## Escalabilidade

- Alta escalabilidade com baixo consumo de recursos.
- Suporta múltiplos acessos simultâneos com infraestrutura mínima.

## Atualizações

- Sim, recebe atualizações constantes.
- Última versão: **v0.125.5 (02/05/2024)**

## Facilidade de Uso

- Pode ser operado por **linha de comando**.
- Para iniciantes, há **interfaces gráficas amigáveis**:
  - Enwrite
  - Lipi
  - Netlify CMS
  - Hokus CMS

## Vantagens

- Carregamento rápido com arquivos pré-renderizados (HTML, CSS, JS).
- Segurança: não utiliza banco de dados.
- Compilação instantânea e publicação rápida.
- Migração rápida de WordPress.
- Suporte a conteúdo ilimitado sem plugins.
- Liberdade de estrutura e modelo para desenvolvedores.
- Baixo custo com infraestrutura (pode rodar em servidor de 1GB RAM).
- Facilidade de hospedagem (qualquer servidor aceita HTML estático).
- Sites mantidos com poucos recursos e fácil manutenção.
- Conteúdo facilmente gerenciado via terminal com arquivos Markdown.

## Desvantagens

- Requer conhecimento técnico em programação.
- Ausência de CMS nativo e interface amigável.
- Difícil encontrar templates e documentações completas.
- Algumas funcionalidades precisam ser manuais.
- Necessário uso de ferramentas de terceiros para:
  - Formulários de contato
  - Comentários
  - Busca interna

## Comparação com WordPress (Opiniões de Usuários)

- WordPress é um CMS dinâmico, baseado em **PHP + MySQL**.
- Hugo evita complexidades de banco de dados e consumo elevado de RAM.
- WordPress exige muitos ajustes para alcançar boa performance.
- Hugo oferece:
  - **Maior desempenho**
  - **Menor custo de manutenção**
  - **Menos dores de cabeça com backup, cache, lentidão etc.**

> "Construí um site com muitos dados com o Hugo e é horrível. O mecanismo de modelo é muito ruim. Difícil escrever pequenas funções reutilizáveis..."  
> [Discussão completa](https://news.ycombinator.com/item?id=24670439)

> "Antes de colocar um MySQL gigantesco na sua aplicação, pense: você realmente precisa de um banco de dados? Com Hugo, você pode ter um site robusto sem isso."

> "Mesmo com otimizações no WordPress, ele ainda é mais lento comparado a sites estáticos com Hugo."

## Comando Curioso

- Comando `hugo -V`:  
  Gera uma pasta `public` com os arquivos HTML, prontos para serem enviados ao servidor remoto (ex: Apache).

## Referências

- [https://serverdo.in/hugo-sites-estaticos/](https://serverdo.in/hugo-sites-estaticos/)  
- [https://gohugo.io/](https://gohugo.io/)  
- [https://dev.to/feministech/pt-br-hugo-a-forma-mais-rapida-de-fazer-um-site-5hk7](https://dev.to/feministech/pt-br-hugo-a-forma-mais-rapida-de-fazer-um-site-5hk7)  
- [https://brito.com.br/posts/hugo-gerador-sites/](https://brito.com.br/posts/hugo-gerador-sites/)  
- [https://kinsta.com/pt/blog/site-estatico-hugo/](https://kinsta.com/pt/blog/site-estatico-hugo/)  
- [https://www.youtube.com/watch?v=G6GAUO2PNXU](https://www.youtube.com/watch?v=G6GAUO2PNXU)  
- [https://www.youtube.com/watch?v=927wgzzNMEA](https://www.youtube.com/watch?v=927wgzzNMEA)  
- [https://www.strattic.com/jekyll-hugo-wordpress-pros-cons-static-site-generators](https://www.strattic.com/jekyll-hugo-wordpress-pros-cons-static-site-generators)  
- [https://www.sanity.io/glossary/hugo](https://www.sanity.io/glossary/hugo)  
- [https://strapi.io/blog/guide-to-using-hugo-site-generator](https://strapi.io/blog/guide-to-using-hugo-site-generator)  
- [https://tableless.com.br/primeiros-passos-com-hugo/](https://tableless.com.br/primeiros-passos-com-hugo/)
